@@ -174,23 +174,14 @@ class Qctrl:
             The status of the action.
         action_type : str
             The action type.
-
-
-        Returns
-        -------
-        None
-            instead of returning a query. It will print out the formatted query result.
         """
 
         query = ActivityMonitorQuery(self.gql_api)
-
-        return print(
-            query(
-                limit=limit,
-                offset=offset,
-                status=status,
-                action_type=action_type,
-            )
+        query(
+            limit=limit,
+            offset=offset,
+            status=status,
+            action_type=action_type,
         )
 
     def get_result(
